clear;
load('pp_CPSM_Shared.mat');

assert(D.numVids==size(D.vidData,1)); %Number of videos.
assert(D.numVids==size(D.vidLabBits,1));
assert(D.numClass==size(D.classProps,2)); %Number of classes.
assert(all(D.classProps==sum(D.vidLabBits,1))); %Class proportions.

%% Try to classify videos. 
disp('Try to KNN classify');
for classID = 1 : 10
    % Setup a binary problem.
    lab = (D.vidLabBits(:,classID)==1)+1; 
    Ytrain = lab(1:2:end);
    Ytest  = lab(2:2:end);
    Xtrain = D.vidDataNorm(1:2:end,:);
    Xtest  = D.vidDataNorm(2:2:end,:);

    % Classify. (Need matlab bioinfs toolbox)
    c = knnclassify(Xtest, Xtrain, Ytrain);

    acc = sum(c==Ytest)/numel(Ytest);
    fprintf(1,'Classify %18s vs all. Acc: %1.2f.\n', D.classNames{classID}, acc);
end

%% Verify the videos
disp('Checking videos..');
for c = 1: D.numVids
    assert(exist(['CPSM_data/', D.vidNames{c}],'file')>0);
end
    
%% Show the video.
v = 30;
idx = (D.descriptor_xytvc(:,4)==v); %Index for this video.
descr = D.descriptor_xytvc(idx,:);  %Descriptors for this video.
clust_v = descr(:,5);               %K-NN class for each descriptor.
h1 = hist(clust_v,1:2000);
h2 = D.vidData(v,:); 
assert(all(h1==h2)); %Sanity check.
obj=VideoReader(['CPSM_data/', D.vidNames{v}]);

%%
sfigure(1); clf;
axis tight; axis image; set(gcf,'doublebuffer','on'); 
for f = 1:2:obj.NumberOfFrames
    cla;
    imshow(obj.read(f));hold on;
    idx = (descr(:,3)==f); %Get index for this frame.
    plot(descr(idx,1), descr(idx,2), 'bo');
    drawnow;
    pause(0.01);
end